NetworkService class abstract

Implementers

Constructors

NetworkService()

Properties

baseUrl → String
no setter
hashCode → int
The hash code for this object.
no setterinherited
headers → Map<String, Object>
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timeout → int
no setter

Methods

delete(String endpoint, {Map<String, dynamic>? queryParameters, Map<String, dynamic>? data}) → Future<BaseCallBack<AppException, BaseResponse>>
get(String endpoint, {Map<String, dynamic>? queryParameters, Map<String, dynamic>? data}) → Future<BaseCallBack<AppException, BaseResponse>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
post(String endpoint, {Map<String, dynamic>? queryParameters, Map<String, dynamic>? data}) → Future<BaseCallBack<AppException, BaseResponse>>
postFormData(String endpoint, {Map<String, dynamic>? queryParameters, FormData? data}) → Future<BaseCallBack<AppException, BaseResponse>>
put(String endpoint, {Map<String, dynamic>? queryParameters, Map<String, dynamic>? data}) → Future<BaseCallBack<AppException, BaseResponse>>
toString() → String
A string representation of this object.
inherited
updateHeader(Map<String, dynamic> data) → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited