S class
Constructors
- S()
Properties
- empty_app_id → String
-
App ID chưa được nhậpno setter - empty_english_accent → String
-
English Accent chưa được nhậpno setter - empty_file → String
-
File không có giá trịno setter - empty_reference_text → String
-
Reference Text chưa được nhậpno setter - empty_request_id → String
-
Request id không có giá trịno setter - empty_secret_key → String
-
Secret Key chưa được nhậpno setter - english_accent_value → String
-
en-usno setter - hashCode → int
-
The hash code for this object.
no setterinherited
- ioe_bad_request → String
-
Lỗi xử lý truy vấnno setter - ioe_dont_connect_to_server → String
-
Không thể kết nối đến serverno setter - ioe_dont_recogize_pronunciation → String
-
Không nhận ra phát âmno setter - ioe_failure → String
-
Thất bạino setter - ioe_init_not_success → String
-
Khởi tạo sdk thất bạino setter - ioe_internal_server_error → String
-
Lỗi nội bộ máy chủno setter - ioe_loading → String
-
Đang tải…no setter - ioe_no_network → String
-
Vui lòng kiểm tra lại kết nối và thử lạino setter - ioe_session_expire → String
-
Phiên làm việc hết hạn.no setter - ioe_sever_time_out → String
-
Server không phản hồino setter - ioe_success → String
-
Thành côngno setter - ioe_unknown_error → String
-
Không nhận diện được, vui lòng thử lạino setter - message_error_evaluate_process → String
-
Xảy ra lỗi trong quá trình đánh giáno setter - message_error_record_process → String
-
Xảy ra lỗi trong quá trinh ghi âmno setter - message_no_detect_speech → String
-
Không phát hiện giọng nóino setter - message_permission_audio_storage_denied → String
-
Record audio and storage permission denied!no setter - message_recorder_not_initial → String
-
IOE recorder not initialno setter - message_sdk_not_initial → String
-
IOE sdk not initialno setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- text_timeout_exception → String
-
Server không phản hồino setter - text_unknown_error → String
-
Lỗi không xác địnhno setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
load(
Locale locale) → Future< S> -
maybeOf(
BuildContext context) → S? -
of(
BuildContext context) → S
Constants
- delegate → const AppLocalizationDelegate